#!/usr/bin/env python
# coding: utf-8

# In[1]:


import numpy as np
import nltk
from nltk.book import *


# ## NLTK book Ch. 1, sec. 3 Simple statistics

# In[2]:


fdist1 = nltk.FreqDist(text1)
fdist1


# In[3]:


fdist1.max()


# In[4]:


fdist1.most_common(50)


# In[5]:


fdist1.plot(50)


# In[6]:


fdist1.plot(50, cumulative=True)


# In[7]:


fdist1["whale"]


# In[8]:


fdist1.freq("whale")


# In[9]:


fdist1.tabulate(5)


# ### Exercises

# In[10]:


# Exercise 1
def my_frequency(j):
    d={}
    for it in j:
        if it not in d:
            d[it]=1
        else:
            d[it]+=1
    return d


# In[11]:


a = """this is a stupid sentence
this is also stupid
this not sentence""".split()
a


# In[12]:


my = my_frequency(a)


# In[13]:


my.items()


# In[14]:


my.keys()


# In[15]:


my.values()


# In[16]:


my.values()


# #### Comparing to Counter

# In[17]:


from collections import Counter


# In[18]:


myc = Counter(a)


# In[19]:


myc.keys()


# In[20]:


myc.most_common(3)


# ## Exercise 2

# In[21]:


# NLTK Ch. 1 Exercise 27
def vocab_size(text):
    # text is list of tokens
    fd = nltk.FreqDist(text)
    return len(fd.keys())


# In[22]:


vocab_size(text1)


# In[23]:


vocab_size(text9)


# In[24]:


# NLTK Ch. 1 Exercise 28
def percent(word, text): 
    return 100*text.count(word)/len(text)


# In[25]:


percent('the', text1)


# ## NLTK book, Ch. 2, Sec. 1.0-1.5 Accessing Text Copora

# In[26]:


emma = nltk.corpus.gutenberg.words('austen-emma.txt')
len(emma)


# In[27]:


from nltk.corpus import gutenberg
for fileid in gutenberg.fileids():
    num_chars = len(gutenberg.raw(fileid)) 
    num_words = len(gutenberg.words(fileid))
    num_sents = len(gutenberg.sents(fileid))
    num_vocab = len(set(w.lower() for w in gutenberg.words(fileid)))
    print(round(num_chars/num_words, 2), round(num_words/num_sents), round(num_words/num_vocab), fileid)


# In[28]:


from nltk.corpus import webtext
for fileid in webtext.fileids():
    print(fileid, webtext.raw(fileid)[:65], '...')


# In[29]:


from nltk.corpus import brown
brown.categories()


# In[30]:


news_text = brown.words(categories='news')
fdist = nltk.FreqDist(w.lower() for w in news_text)
modals = ['can', 'could', 'may', 'might', 'must', 'will']
for m in modals:
    print(m + ':', fdist[m], end=' ')


# In[31]:


fmdist = nltk.FreqDist(w.lower() for w in news_text if w.lower() in modals)
for m in modals:
    print(m + ':', fmdist[m], end=' ')


# In[32]:


fmdist.plot()


# ## Exercise 3

# In[33]:


# Exercise 3
# How to handle lower case?
labels = ['i', 'we', 'he', 'she', 'they']

brown_freq=nltk.FreqDist(
    [w.lower() for w in brown.words() if
     w.lower() in set(labels)])

# To replace 'i' with 'I' as key:
v=brown_freq.pop('i')
brown_freq['I']=v

brown_freq.tabulate()
brown_freq.plot()


# In[34]:


# Exercise 4
# the following does not do lower case correctly
cond = nltk.ConditionalFreqDist([(genre,word)
for genre in ['news','fiction']
for word in brown.words(categories=genre)
if word in set(labels)])

# to get lower case:
cf_low = nltk.ConditionalFreqDist([(genre,word.lower())
for genre in ['news','fiction']
for word in brown.words(categories=genre)
if word.lower() in set(labels)])

# to decorate the result:
cf_low['news']['I']=cf_low['news'].pop('i')
cf_low['fiction']['I']=cf_low['fiction'].pop('i')

print("\nTable without case folding:")
cond.tabulate()

print("\nTable with case folding:")
cf_low.tabulate()


# In[35]:


cf_low.plot()


# ## matplotlib

# In[36]:


import matplotlib.pyplot as plt
plt.plot(np.arange(10))
plt.show()


# ### Exercise 5

# In[37]:


plt.plot(np.arange(len(brown_freq)), [f for w,f in brown_freq.most_common()])
plt.xticks(np.arange(len(brown_freq)),[w for w,f in brown_freq.most_common()])
plt.xlabel('Samples')
plt.ylabel('Counts')
plt.show()


# ### Exercise 6

# In[38]:


xs = sorted([k for k in brown_freq.keys()])


# In[39]:


plt.bar(np.arange(len(brown_freq)),
        [brown_freq[k] for k in xs],
        tick_label=xs)
plt.show()


# Observe that *I* is sorted before *he* because of the capital.

# In[40]:


plt.bar( np.arange(len(brown_freq)),
        [f for w,f in brown_freq.most_common()],
        tick_label=[w for w,f in brown_freq.most_common()])
plt.show()


# ### Exercise 7

# In[41]:


plt.hist([len(sent) for sent in brown.sents()])
plt.show()


# In[42]:


plt.hist([len(sent) for sent in brown.sents()], range(0,100,10))
plt.show()


# ### Exercise 8

# In[43]:


plt.boxplot([len(sent) for sent in brown.sents()])
plt.show()

